@@ -77,7 +77,36 @@ def create_networkx_graph(event_ids: list, include_last: bool):
     return graph
 
 
+def nx2pyvis(nx_graph, pyvisnet, default_node_size=1, default_edge_weight=1):
+    edges = nx_graph.edges(data=True)
+    nodes = nx_graph.nodes(data=True)
+
+    if len(edges) > 0:
+        for e in edges:
+            if 'size' not in nodes[e[0]].keys():
+                nodes[e[0]]['size'] = default_node_size
+            nodes[e[0]]['size'] = int(nodes[e[0]]['size'])
+            if 'size' not in nodes[e[1]].keys():
+                nodes[e[1]]['size'] = default_node_size
+            nodes[e[1]]['size'] = int(nodes[e[1]]['size'])
+            pyvisnet.add_node(e[0], **nodes[e[0]], title="Hi")
+            pyvisnet.add_node(e[1], **nodes[e[1]], title="Hi")
+
+            if 'weight' not in e[2].keys():
+                e[2]['weight'] = default_edge_weight
+            # e[2]['weight'] = e[2]['weight']
+            edge_dict = e[2]
+            edge_dict["value"] = edge_dict.pop("weight")
+            pyvisnet.add_edge(e[0], e[1], **edge_dict)
+
+    for node in nx.isolates(nx_graph):
+        if 'size' not in nodes[node].keys():
+            nodes[node]['size'] = default_node_size
+        pyvisnet.add_node(node, **nodes[node], title="Hi")
+
+    return pyvisnet
+
+
 if __name__ == '__main__':
     print(create_graph_as_dict("A,B,C,B,C,A,D".split(","), False))
     print(create_position_embeddings("A,B,C,B,C,A,D".split(","), False))
-
